function fbrFromTrackVis = trk_to_fbr(XOffset,YOffset,ZOffset)
%fbr = trk_to_fbr(XOffset,YOffset,ZOffset)
%
%Converts TrackVis trk files to BrainVoyager fbr files
%
%Requires BVQXTools/Neuroelf http://www.neuroelf.net 
%and TrackVis read/write tools from John Colby
%https://github.com/johncolby/along-tract-stats
%
%help for this file on
%http://support.brainvoyager.com/ > DWI > Interaction with other software

%DISCLAIMER: this is an experimental function. Brain Innovation BV makes no representations or
%warranties of any kind concerning the safety, suitability, lack of
% inaccuracies, typographical errors, or other harmful components
%of this function.

%(c) Pim Pullens -- Brain Innovation BV, Maastricht NL
% May 31, 2011

%get trackvis file
@trk_getfile;

[header,tracts,fname]=trk_getfile;

disp(['TrackVis file: ',fname]);

nfibers = header.n_count;
dimX = header.dim(1); %DWI dimensions!
dimY = header.dim(2);
dimZ = header.dim(3);
origin = [0 0 0];

%set up fbr
fbr = BVQXfile('new:fbr');
fbr.Group.NrOfFibers = nfibers;
fbr.FibersOriginX = 0;
fbr.FibersOriginY = 0;
fbr.FibersOriginZ = 0;

%XOffset for CG: 128
%YOffset for CG: 128
%ZOffset for CG: 72

for i=1:nfibers, 
        fbr.Group.Fiber(i).NrOfPoints = tracts(i).nPoints;
        fbr.Group.Fiber(i).FiberPoints = ones(tracts(i).nPoints,6)*100;
        %fbr_FiberPoints = applybvtrf(tracts(i).matrix,trf_total);
        fbr_FiberPoints = tracts(i).matrix;
        fbr.Group.Fiber(i).FiberPoints(:,1) = fbr_FiberPoints(:,2)-YOffset;  %y-coord in openGL
        fbr.Group.Fiber(i).FiberPoints(:,2) = -fbr_FiberPoints(:,3)+ZOffset; %z-coord in openGL
        fbr.Group.Fiber(i).FiberPoints(:,3) = fbr_FiberPoints(:,1)-XOffset; %x-coord
end

fbr.Group.Name = '"imported from TrackVis"';
fbr.SaveAs

fbrFromTrackVis = fbr;

function [header,tracts,fname] = trk_getfile()

[fname,pname] = uigetfile('*.trk','Select TrackVis *.trk file...');

trk_fullpath = [pname,fname];

[header,tracts]=trk_read(trk_fullpath);